Function iron_valid::validate [−] [src]

pub fn validate(rules: BTreeMap<&'static str, Vec<Rule>>, values: Map) -> Result<Map, BTreeMap<&'static str, Vec<String>>>

Validate a map of values against a map of rules.

Returns a Result containing a map of post-processed values, or a map of validation error messages.